@@ -9,7 +9,7 @@ use POE::Component::IRC::Common qw(l_irc matches_mask_array);
 use POE::Component::IRC::Plugin qw(PCI_EAT_NONE);
 use POE::Component::IRC::Plugin::BotAddressed;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub new {
     my ($package, %args) = @_;
@@ -153,16 +153,6 @@ sub S_001 {
     return PCI_EAT_NONE;
 }
 
-sub S_public {
-    my ($self, $irc) = splice @_, 0, 2;
-    my $user         = ${ $_[0] };
-    my $chan         = ${ $_[1] }->[0];
-    my $what         = ${ $_[2] };
-
-    $poe_kernel->post($self->{session_id} => _own_handler => $user, $chan, $what);
-    return PCI_EAT_NONE;
-}
-
 sub S_ctcp_action {
     my ($self, $irc) = splice @_, 0, 2;
     my $user         = ${ $_[0] };
@@ -170,14 +160,24 @@ sub S_ctcp_action {
     my $what         = ${ $_[2] };
 
     return PCI_EAT_NONE if $chan !~ /^[#&!]/;
+    $poe_kernel->post($self->{session_id} => _own_handler => $user, $chan, $what);
+    return PCI_EAT_NONE;
+}
+
+sub S_bot_addressed {
+    my ($self, $irc) = splice @_, 0, 2;
+    my $user         = ${ $_[0] };
+    my $chan         = ${ $_[1] }->[0];
+    my $what         = ${ $_[2] };
+
     $poe_kernel->post($self->{session_id} => _other_handler => $user, $chan, $what);
     return PCI_EAT_NONE;
 }
 
 no warnings 'once';
-*S_bot_addressed        = \&S_ctcp_action;
-*S_bot_mentioned        = \&S_ctcp_action;
-*S_bot_mentioned_action = \&S_ctcp_action;
+*S_public               = \&S_ctcp_action;
+*S_bot_mentioned        = \&S_bot_addressed;
+*S_bot_mentioned_action = \&S_bot_addressed;
 
 1;
 __END__
